==> onos-yang-runtime-2.2.0-b1-sources.jar: org/onosproject/yang/gen/v1/augmentchoice/rev20160826/augmentchoice/contenttest/augmentedschcontenttest/DefaultAugChoiceModKey.java <==
/*
 * Copyright 2017-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.augmentchoice.rev20160826.augmentchoice.contenttest.augmentedschcontenttest;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.ytbchoicewithcontainerandleaflist.rev20160826.ytbchoicewithcontainerandleaflist.ContentTest;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of augChoiceModKey.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultAugChoiceModKey extends InnerModelObject implements AugChoiceModKey {
    protected List<org.onosproject.yang.gen.v1.augmentchoice.rev20160826.augmentchoice.contenttest.augmentedschcontenttest.augchoicemodkey.AugChoiceModKey> augChoiceModKey;

    @Override
    public List<org.onosproject.yang.gen.v1.augmentchoice.rev20160826.augmentchoice.contenttest.augmentedschcontenttest.augchoicemodkey.AugChoiceModKey> augChoiceModKey() {
        return augChoiceModKey;
    }

    @Override
    public void augChoiceModKey(List<org.onosproject.yang.gen.v1.augmentchoice.rev20160826.augmentchoice.contenttest.augmentedschcontenttest.augchoicemodkey.AugChoiceModKey> augChoiceModKey) {
        this.augChoiceModKey = augChoiceModKey;
    }

    @Override
    public void addToAugChoiceModKey(org.onosproject.yang.gen.v1.augmentchoice.rev20160826.augmentchoice.contenttest.augmentedschcontenttest.augchoicemodkey.AugChoiceModKey addTo) {
        if (augChoiceModKey == null) {
            augChoiceModKey = new ArrayList<>();
        }
        augChoiceModKey.add(addTo);
    }


    @Override
    public int hashCode() {
        return Objects.hash(augChoiceModKey);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultAugChoiceModKey) {
            DefaultAugChoiceModKey other = (DefaultAugChoiceModKey) obj;
            return
                Objects.equals(augChoiceModKey, other.augChoiceModKey);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("augChoiceModKey=" + augChoiceModKey)
            .toString();
    }


    /**
     * Creates an instance of defaultAugChoiceModKey.
     */
    public DefaultAugChoiceModKey() {
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/augmentchoice/rev20160826/augmentchoice/contenttest/augmentedschcontenttest/DefaultAugChoiceModKey.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.augmentchoice.rev20160826.augmentchoice.contenttest.augmentedschcontenttest;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.ytbchoicewithcontainerandleaflist.rev20160826.ytbchoicewithcontainerandleaflist.ContentTest;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of augChoiceModKey.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultAugChoiceModKey extends InnerModelObject implements AugChoiceModKey {
    protected List<org.onosproject.yang.gen.v1.augmentchoice.rev20160826.augmentchoice.contenttest.augmentedschcontenttest.augchoicemodkey.AugChoiceModKey> augChoiceModKey;

    @Override
    public List<org.onosproject.yang.gen.v1.augmentchoice.rev20160826.augmentchoice.contenttest.augmentedschcontenttest.augchoicemodkey.AugChoiceModKey> augChoiceModKey() {
        return augChoiceModKey;
    }

    @Override
    public void augChoiceModKey(List<org.onosproject.yang.gen.v1.augmentchoice.rev20160826.augmentchoice.contenttest.augmentedschcontenttest.augchoicemodkey.AugChoiceModKey> augChoiceModKey) {
        this.augChoiceModKey = augChoiceModKey;
    }

    @Override
    public void addToAugChoiceModKey(org.onosproject.yang.gen.v1.augmentchoice.rev20160826.augmentchoice.contenttest.augmentedschcontenttest.augchoicemodkey.AugChoiceModKey addTo) {
        if (augChoiceModKey == null) {
            augChoiceModKey = new ArrayList<>();
        }
        augChoiceModKey.add(addTo);
    }


    @Override
    public int hashCode() {
        return Objects.hash(augChoiceModKey);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultAugChoiceModKey) {
            DefaultAugChoiceModKey other = (DefaultAugChoiceModKey) obj;
            return
                Objects.deepEquals(augChoiceModKey, other.augChoiceModKey);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("augChoiceModKey=" + augChoiceModKey)
            .toString();
    }


    /**
     * Creates an instance of defaultAugChoiceModKey.
     */
    public DefaultAugChoiceModKey() {
    }

}
